@@ -9,7 +9,7 @@ use PerlX::Maybe qw( maybe );
 use Path::Class qw( dir );
 
 # ABSTRACT: Handle data types automatically
-our $VERSION = '1.17'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 
 sub _default_coders
@@ -140,7 +140,7 @@ Clustericious::Plugin::AutodataHandler - Handle data types automatically
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 SYNOPSIS
 
@@ -150,7 +150,7 @@ version 1.17
  
  get '/some/route' => sub {
    my $c = shift;
-   $c->{autodata} = { x => 1, y => 'hello, z => [1,2,3] };
+   $c->stash->{autodata} = { x => 1, y => 'hello, z => [1,2,3] };
  };
 
 =head1 DESCRIPTION
