@@ -6,20 +6,23 @@ use Clustericious::Log;
 use Mojo::ByteStream qw/b/;
 use Mojo::URL;
 use Mojo::Base 'Mojolicious::Plugin';
+use JSON::MaybeXS qw( encode_json );
 
 # ABSTRACT: Plugin for clustericious to use PlugAuth.
-our $VERSION = '1.17'; # VERSION
+our $VERSION = '1.18'; # VERSION
 
 
 has 'config_url';
 
 sub register {
     my ($self, $app, $conf) = @_;
-    eval { $self->config_url($conf->{plug_auth}->url(default => '')) };
-    if ($@ || !$self->config_url) {
+    my $url = eval { $conf->{plug_auth}->url(default => '') };
+    $url =~ s{/$}{} if defined $url;
+    if ($@) {
         WARN "unable to determine PlugAuth URL: $@";
         return $self;
     }
+    $self->config_url($url);
     $self;
 }
 
@@ -63,11 +66,11 @@ sub authenticate {
                     WARN "PlugAuth returned code " . $res->code;
                 }
             } else {
-                my ( $message, $code ) = $tx->error;
-                if ($code) {
-                    TRACE "Not VIP $config_url/host/$ip/trusted : $code $message";
+                my $error = $tx->error;
+                if ($error->{code}) {
+                    TRACE "Not VIP $config_url/host/$ip/trusted : @{[ $error->{code} ]} @{[ $error->{message} ]}";
                 } else {
-                    WARN "Error connecting to PlugAuth at $config_url/host/$ip/trusted : $message";
+                    WARN "Error connecting to PlugAuth at $config_url/host/$ip/trusted : @{[ encode_json $error ]}";
                 }
             }
         };
@@ -88,11 +91,11 @@ sub authenticate {
 
             if(!defined $check || $check == 503) {
                 $c->res->headers->www_authenticate(qq[Basic realm="$realm"]);
-                my ( $message, $code ) = $tx->error;
-                if ($code) {
-                    WARN "Error connecting to PlugAuth at $auth_url : $code $message";
+                my $error = $tx->error;
+                if ($error->{code}) {
+                    WARN "Error connecting to PlugAuth at $auth_url : @{[ $error->{code} ]} @{[ $error->{message} ]}";
                 } else {
-                    WARN "Error connecting to PlugAuth at $auth_url : $message";
+                    WARN "Error connecting to PlugAuth at $auth_url : @{[ encode_json $error ]}";
                 }
                 $c->render(text => "auth server down", status => 503); # "Service unavailable"
                 return;
@@ -163,7 +166,7 @@ Clustericious::Plugin::PlugAuth - Plugin for clustericious to use PlugAuth.
 
 =head1 VERSION
 
-version 1.17
+version 1.18
 
 =head1 SYNOPSIS
 
